@@ -117,6 +117,9 @@ class data(basedata):
             settings=self.settings
         )
 
+        # CLEAN UP TASKS TO MAKE THE TICKET UPDATE
+        self.clean_up()
+
         self.log.debug('completed the ``ingest`` method')
         return None
 
